@@ -13,7 +13,7 @@ from jss.connection import JssClient
 
 logger = logging.getLogger(__name__)
 
-class Storage(coreboto.Base):
+class Storage(driver.Base):
 
     def __init__(self, path=None, config=None):
         self._access_key = config.jss_accesskey
@@ -55,6 +55,7 @@ class Storage(coreboto.Base):
         try:
             object_instance = self._jss.bucket(self._bucket).object(path1)
             res = object_instance.download_flow()
+            logger.info("get_content res:%s" % res)
             while True:
                 data = res.read(1024)
                 if len(data) != 0:
